@@ -3,7 +3,7 @@ package Net::FullAuto::ISets::Amazon::Catalyst_is;
 ### OPEN SOURCE LICENSE - GNU AFFERO PUBLIC LICENSE Version 3.0 #######
 #
 #    Net::FullAuto - Powerful Network Process Automation Software
-#    Copyright © 2000-2015  Brian M. Kelly
+#    Copyright © 2000-2016  Brian M. Kelly
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as
@@ -134,7 +134,6 @@ END
       IPC::System::Simple
       Sub::Identify
       Fatal
-      #B::C   # Needs ExtUtils::Embed
       Sub::Name
       Role::Tiny
       Test::LeakTrace
@@ -591,7 +590,8 @@ END
    ($stdout,$stderr)=$handle->cmd("chmod 644 User.pm");
    ($stdout,$stderr)=$handle->cwd('../../../..');
    ($stdout,$stderr)=$handle->cmd(
-      "wget https://github.com/pangyre/p5-myapp-10in10/archive/master.zip",
+      "wget --random-wait --progress=dot ".
+      "https://github.com/pangyre/p5-myapp-10in10/archive/master.zip",
       '__display__');
    ($stdout,$stderr)=$handle->cmd("unzip master.zip",'__display__');
    ($stdout,$stderr)=$handle->cmd("rm -rvf master.zip",'__display__');
@@ -643,7 +643,7 @@ END
           |_| \_|\___|\__|     |_|   \__,_|_|_/_/   \_\__,_|\__\___/ ©
 
 
-   Copyright © 2000-2015  Brian M. Kelly  Brian.Kelly@FullAuto.com
+   Copyright © 2000-2016  Brian M. Kelly  Brian.Kelly@FullAuto.com
 
 END
    eval {
